@@ -1,11 +1,10 @@
-__version__ = '0.11.3'
+__version__ = '0.12.1'
 
 import os
 
 from .document import Document
 from .array import DocumentArray
-from .dataclasses import dataclass, Image, Text, Audio, JSON, field
-
+from .dataclasses import dataclass, field
 
 if 'DA_NO_RICH_HANDLER' not in os.environ:
     from rich.traceback import install
